﻿#region Working Command
Get-EventLog -LogName Application -Newest 10 -ComputerName localhost -EntryType Warning
#endregion

#region Create Function
function Get-LatestEvent {
    Get-EventLog -LogName Application -Newest 10 -ComputerName LocalHost -EntryType Warning
}
#endregion

#region Identify Variables
function Get-LatestEvent {
    $Log = "Application"
    $Computer = "localhost"
    $LogType = "Warning"
    Get-EventLog -LogName $Log -Newest 10 -ComputerName $Computer -EntryType $LogType
}
#endregion

#region Function with Parameters
function Get-LatestEvent {
    Param(
        [parameter(mandatory=$true)]
        [String]
        $Log,
        [parameter(mandatory=$true)]
        [String]
        $LogType,
        [parameter(mandatory=$false)]
        [String[]]
        $Computer="localhost"
    )

    Get-EventLog -LogName $Log -Newest 10 -ComputerName $Computer -EntryType $LogType
}
#endfunction

#region Add comment based help
function Get-LatestEvent {
    <#
    .Synopsis
       Function retuns the last 10 events.
    .DESCRIPTION
       This function returns the last 10 events from the event log you specify with the entry type that you specify.
    .PARAMETER Log
        This parameter is where you will specify the EventLog you wish to retrieve the events from.
    .PARAMETER LogType
        This is the type of logs you wish to return. Examples include Informational, Warning and Error.
    .PARAMETER ComputerName
       This parameter will be used to specify a single, or an array of computer names which it will retreive the WinRM Service status from.
    .EXAMPLE
       Get-LatestEvent -Log Application -LogType Warning
    .EXAMPLE
       Get-LatestEvent -Log Application -LogType Warning -ComputerName Server1
    #>
    Param(
        [parameter(mandatory=$true)]
        [String]
        $Log,
        [parameter(mandatory=$true)]
        [String]
        $LogType,
        [parameter(mandatory=$false)]
        [String[]]
        $Computer="localhost"
    )

    Get-EventLog -LogName $Log -Newest 10 -ComputerName $Computer -EntryType $LogType
}
#endfunction